@@ -50,9 +50,6 @@
 #'   containing the new index
 #' @param MODIStsp_dir `character` main folder containing MODIStsp R files,
 #'   Default: retrieved from package installation folder
-#' @importFrom gWidgets gbasicdialog ggroup glabel size font gedit gbutton
-#'  svalue addSpace gframe addSpring gmessage visible
-#' @importFrom pacman p_load p_exists
 #' @return The function is called for its side effects. On success, the
 #'  MODIStsp_Previous.json or the json options file specified by the user
 #'  is modified so to allow computation of the additional indexes.
@@ -98,19 +95,12 @@ MODIStsp_addindex <- function(
   # Initialization and retrieval of parameters ----
   if (gui) {
     #nocov start
-    if (!pacman::p_exists("gWidgetsRGtk2", local = TRUE)) {
-      message("Library 'gWidgetsRgtk2' is required to run MODIStsp_addindex ",
-              "in interactive mode but it is not installed! \n\n",
-              "Do you want to install it now?",
-              type = " y / n")
-      inst_gw <- readline()
-      if (inst_gw == "y") {
-        pacman::p_load("gWidgetsRGtk2")
-      } else {
-        stop("MODIStsp can not work in Interactive mode without gWidgetsRGtk2!",
-             "\n Aborting!")
-      }
-
+    if (!all(requireNamespace(c("gWidgets", "gWidgetsRGtk2")))) {
+      stop("You need to install package gWidgets to use MODIStsp GUI. Please install it with:
+                install.packages(c('gWidgets', 'gWidgetsRGtk2')")
+    } else {
+      requireNamespace("gWidgets")
+      requireNamespace("gWidgetsRGtk2")
     }
     options("guiToolkit" = "RGtk2")
     #nocov end
@@ -173,6 +163,13 @@ MODIStsp_addindex <- function(
   # GUI Initialization -----
   if (gui) {
     #nocov start
+    if (!all(requireNamespace(c("gWidgets", "gWidgetsRGtk2")))) {
+      stop("You need to install package gWidgets to use MODIStsp GUI. Please install it with:
+                install.packages(c('gWidgets', 'gWidgetsRGtk2')")
+    } else {
+      requireNamespace("gWidgets")
+      requireNamespace("gWidgetsRGtk2")
+    }
     main_win <- gWidgets::gbasicdialog(
       title = "Insert the new Spectral Index information and formula",
       parent = NULL,
@@ -351,7 +348,7 @@ MODIStsp_addindex <- function(
       text      = "Done !",
       container = but_group,
       handler   = function(h, ...) {
-        dispose(main_win)
+        gWidgets::dispose(main_win)
         gWidgets::gmessage(
           message = "ReOpen the 'Select Layers' window to use the new indexes",
           title = "Done!"
