@@ -28,9 +28,8 @@
 #' @rdname MODIStsp_download
 #' @author Lorenzo Busetto, phD (2014-2017) \email{lbusett@@gmail.com}
 #' @author Luigi Ranghetti, phD (2015) \email{ranghetti.l@@irea.cnr.it}
-#' @importFrom httr RETRY authenticate content GET progress write_disk HEAD config
+#' @importFrom httr RETRY authenticate content GET write_disk
 #' @importFrom xml2 as_list
-#' @importFrom gWidgets gconfirm
 
 MODIStsp_download <- function(modislist,
                               out_folder_mod,
@@ -101,6 +100,13 @@ MODIStsp_download <- function(modislist,
           # retry or abort
           if (gui) {
             #nocov start
+            if (!all(requireNamespace(c("gWidgets", "gWidgetsRGtk2")))) {
+              stop("You need to install package gWidgets to use MODIStsp GUI. Please install it with:
+                install.packages(c('gWidgets', 'gWidgetsRGtk2')")
+            } else {
+              requireNamespace("gWidgets")
+              requireNamespace("gWidgetsRGtk2")
+            }
             confirm <- gWidgets::gconfirm(
               paste0(download_server,
                      "http server seems to be down! Do you want to retry?"),
@@ -166,7 +172,7 @@ MODIStsp_download <- function(modislist,
         }
 
         # Check for errors on download try
-        if (class(download) == "try-error" |
+        if (inherits(download, "try-error") |
             !is.null(attr(download, "status"))) {
           attempt <- attempt + 1
           if (verbose) message("[", date(), "] Download Error - Retrying...")
@@ -202,6 +208,13 @@ MODIStsp_download <- function(modislist,
       if (attempt == n_retries & success == FALSE) {
         if (gui) {
           #nocov start
+          if (!all(requireNamespace(c("gWidgets", "gWidgetsRGtk2")))) {
+            stop("You need to install package gWidgets to use MODIStsp GUI. Please install it with:
+                install.packages(c('gWidgets', 'gWidgetsRGtk2')")
+          } else {
+            requireNamespace("gWidgets")
+            requireNamespace("gWidgetsRGtk2")
+          }
           confirm <- gWidgets::gconfirm(
             paste0(download_server,
                    " server seems to be down! Do you want to retry?"),
