@@ -13,7 +13,7 @@
 #'   3. Creates virtual files of the processed time series.
 #'
 #' Reprojection and resize is dealt with by accessing gdal routines through the
-#' [`gdalUtils`](https://CRAN.R-project.org/package=gdalUtils)
+#' [`gdalUtilities`](https://CRAN.R-project.org/package=gdalUtilities)
 #' package.
 #' Extraction of bitfields from Quality layers is done though bitwise computation
 #' Checks are done in order to not re-download already existing HDF images, and not
@@ -43,7 +43,7 @@
 #' @param start_y `integer [0-17]` Start vertical tile.
 #' @param end_x `integer [0-35]` End horizontal tile.
 #' @param end_y `integer [0-17]` End vertical tile.
-#' @param full_ext `characrter ["FullTiles" | "Resized"]` If \"Full_Ext\", process
+#' @param full_ext `logic` If TRUE, process``
 #'   the entire extent of the selected tiles. Otherwise, crop the output to
 #'   output bbox.
 #' @param bbox `numeric(4)` Output bounding box (xmin, ymin, xmax, ymax) in
@@ -134,13 +134,6 @@
 #'   [Download_and_resampling_of_MODIS_images](http://spatial-analyst.net/wiki/index.php?title=Download_and_resampling_of_MODIS_images))
 #' @note License: GPL 3.0
 #' @rdname MODIStsp_process
-#' @importFrom gdalUtils gdalinfo gdal_translate gdalwarp gdalbuildvrt
-#' @importFrom gWidgets gwindow glabel dispose gconfirm svalue addHandlerUnrealize
-#' @importFrom httr content GET authenticate progress timeout
-#' @importFrom raster raster writeRaster
-#' @importFrom tools file_path_sans_ext
-#' @importFrom parallel detectCores
-#' @importFrom stringr str_sub
 
 MODIStsp_process <- function(sel_prod, start_date, end_date, out_folder,
                              out_folder_mod, reprocess = "Yes",
@@ -167,25 +160,8 @@ MODIStsp_process <- function(sel_prod, start_date, end_date, out_folder,
                              n_retries,
                              verbose) {
 
-  mess_text <- "MODIStsp --> Starting processing"
-  # initialize processing messages in case of interactive execution ----
-
-  if (gui) {
-    #nocov start
-    mess     <- gWidgets::gwindow(title = "Processing Status",
-                                  width = 400,
-                                  height = 40)
-    mess_lab <- gWidgets::glabel(text = paste("---", mess_text, "---"),
-                                 editable = FALSE,
-                                 container = mess)
-    Sys.sleep(0.05)
-    #nocov end
-  } else {
-    mess_lab <- NULL
-  }
-
-  process_message(mess_text, gui, mess_lab, verbose)
 
+  # outproj_str <- sf::st_as_text(sf::st_crs(check_projection(outproj_str)))
   #   __________________________________________________________________________
   #   Intialize processing variables                                        ####
 
@@ -221,8 +197,47 @@ MODIStsp_process <- function(sel_prod, start_date, end_date, out_folder,
   # main output folder --> subfolder of "out_folder" named after the selected
   # MODIS product
   out_prod_folder <- file.path(out_folder, main_out_folder)
+
+  # Preliminary check for MOD19 products: allow processing ONLY if a single tile
+  # is involved.
+
+  if (basename(out_prod_folder) == "MAIA_Land_Surf_BRF_500") {
+    if ((start_x != end_x) | (start_y != end_y)) {
+      warning("Processing for MCD19* products is possible only for one tile at a time! Processing aborted!") #nolint
+      return()
+    }
+  }
+
+
   dir.create(out_prod_folder, showWarnings = FALSE, recursive = TRUE)
 
+  mess_text <- "MODIStsp --> Starting processing"
+  # initialize processing messages in case of interactive execution ----
+
+  if (gui) {
+    #nocov start
+    if (!all(requireNamespace(c("gWidgets", "gWidgetsRGtk2")))) {
+      stop("You need to install package gWidgets to use MODIStsp GUI. Please install it with:
+                install.packages(c('gWidgets', 'gWidgetsRGtk2')")
+    } else {
+      requireNamespace("gWidgets")
+      requireNamespace("gWidgetsRGtk2")
+    }
+    mess     <- gWidgets::gwindow(title = "Processing Status",
+                                  width = 400,
+                                  height = 40)
+    mess_lab <- gWidgets::glabel(text = paste("---", mess_text, "---"),
+                                 editable = FALSE,
+                                 container = mess)
+    Sys.sleep(0.05)
+    #nocov end
+  } else {
+    mess_lab <- NULL
+  }
+
+  process_message(mess_text, gui, mess_lab, verbose)
+
+
   # get start/end years from start_date/end_date
   start_year <- unlist(strsplit(start_date, "[.]"))[1]
   end_year   <- unlist(strsplit(end_date, "[.]"))[1]
@@ -270,7 +285,6 @@ MODIStsp_process <- function(sel_prod, start_date, end_date, out_folder,
     sensor   <- c("Terra")
     combined <- TRUE
   }
-
   #  If both platforms selected, do a cycle. Process first Terra then Aqua.
 
   for (sens_sel in sensor) {
@@ -611,6 +625,13 @@ MODIStsp_process <- function(sel_prod, start_date, end_date, out_folder,
 
   if (gui) {
     #nocov start
+    if (!all(requireNamespace(c("gWidgets", "gWidgetsRGtk2")))) {
+      stop("You need to install package gWidgets to use MODIStsp GUI. Please install it with:
+                install.packages(c('gWidgets', 'gWidgetsRGtk2')")
+    } else {
+      requireNamespace("gWidgets")
+      requireNamespace("gWidgetsRGtk2")
+    }
     gWidgets::addHandlerUnrealize(mess_lab, handler = function(h, ...) {
       return(FALSE)
     })		# Allow message lab to be closed since processing ended .
