@@ -26,9 +26,8 @@
 #' @author Lorenzo Busetto, phD (2014-2017) \email{busetto.l@@irea.cnr.it}
 #' @author Luigi Ranghetti, phD (2016-2017) \email{lbusett@@gmail.com}
 #' @note License: GPL 3.0
-#' @importFrom gWidgets gconfirm
-#' @importFrom httr GET authenticate timeout content
-#' @importFrom stringr str_extract str_split str_split_fixed str_sub
+#' @importFrom stringr str_sub str_split
+#' @importFrom httr RETRY authenticate content
 
 get_mod_dirs <- function(http,
                          download_server,
@@ -62,8 +61,15 @@ get_mod_dirs <- function(http,
       # On interactive execution, after n_retries attempt ask if quit or ----
       # retry
 
-      if (class(response) == "try-error" || response$status_code != 200) {
+      if (inherits(response, "try-error") || response$status_code != 200) {
         if (gui) {
+          if (!all(requireNamespace(c("gWidgets", "gWidgetsRGtk2")))) {
+            stop("You need to install package gWidgets to use MODIStsp GUI. Please install it with:
+                install.packages(c('gWidgets', 'gWidgetsRGtk2')")
+          } else {
+            requireNamespace("gWidgets")
+            requireNamespace("gWidgetsRGtk2")
+          }
           #nocov start
           switch <- gWidgets::gconfirm(
             "http server seems to be down! Do you want to retry?",
