@@ -1,11 +1,18 @@
 #' @title gh_help
 #' @description Helper function used to create an "help button" within the GUI
 #' @noRd
-#' @importFrom gWidgets gbasicdialog glabel gbutton visible
 #' @importFrom utils browseURL
 #' @noRd
 gh_help <- function(h, sel_help, help_messages, info_addr = NULL) {
   #nocov start
+  if (!all(requireNamespace(c("gWidgets", "gWidgetsRGtk2")))) {
+    stop("You need to install package gWidgets to use MODIStsp GUI. Please install it with:
+                install.packages(c('gWidgets', 'gWidgetsRGtk2')")
+  } else {
+    requireNamespace("gWidgets")
+    requireNamespace("gWidgetsRGtk2")
+  }
+
 
   which_help <- NULL
   help_box <- gWidgets::gbasicdialog(title      = "Help",
