@@ -8,10 +8,10 @@
 
 
 context("MODIStsp Test 5: HTTP download from USGS, resize and reproject")
-testthat::test_that(
+test_that(
   "Tests on MODIStsp", {
     skip_on_cran()
-    # skip_on_travis()
+    skip_on_travis()
 
     MODIStsp(test = 5)
     out_files_tif <- list.files(
