@@ -1,5 +1,5 @@
 context("Check proper functioning of the main MODIStsp GUI")
-testthat::test_that(
+test_that(
   "Tests on MODIStsp_GUI", {
     skip_on_cran()
     skip_on_travis()
